pub struct Annotation {
pub core_colon_comment: Option<String>,
pub core_colon_freq_lower_edge: Option<f32>,
pub core_colon_freq_upper_edge: Option<f32>,
pub core_colon_generator: Option<String>,
pub core_colon_label: Option<String>,
pub core_colon_sample_count: i32,
pub core_colon_sample_start: i32,
pub core_colon_uuid: Option<Uuid>,
}Fields
core_colon_comment: Option<String>A human-readable comment
core_colon_freq_lower_edge: Option<f32>The frequency (Hz) of the lower edge of the feature described by this annotation.
core_colon_freq_upper_edge: Option<f32>The frequency (Hz) of the upper edge of the feature described by this annotation.
core_colon_generator: Option<String>Human-readable name of the entity that created this annotation.
core_colon_label: Option<String>A short form human/machine-readable label for the annotation. CAN BE USED TO LABEL CLASSIFIER OUTPUT
core_colon_sample_count: i32The number of samples that this Segment applies to.
core_colon_sample_start: i32The sample index at which this Segment takes effect
core_colon_uuid: Option<Uuid>RFC-4122 unique identifier.
Implementations
Sourceimpl Annotation
impl Annotation
pub fn new( core_colon_sample_count: i32, core_colon_sample_start: i32, ) -> Annotation